@@ -1,6 +1,6 @@
-use v5.20.0;
+use v5.26.0;
 use warnings;
-package Pod::Weaver::PluginBundle::RJBS 5.023;
+package Pod::Weaver::PluginBundle::RJBS 5.024;
 # ABSTRACT: RJBS's default Pod::Weaver config
 
 #pod =head1 OVERVIEW
@@ -61,64 +61,68 @@ sub mvp_bundle_config {
 
 my %WINDOW;
 
-$WINDOW{toolchain} = <<'END';
-This module is part of CPAN toolchain, or is treated as such.  As such, it
-follows the agreement of the Perl Toolchain Gang to require no newer version of
-perl than v5.8.1.  This version may change by agreement of the Toolchain Gang,
-but for now is governed by the L<Lancaster
-Consensus|https://github.com/Perl-Toolchain-Gang/toolchain-site/blob/master/lancaster-consensus.md>
-of 2013.
-END
+$WINDOW{none} = <<~'END';
+  This code is effectively abandonware.  Although releases will sometimes be
+  made to update contact info or to fix packaging flaws, bug reports will
+  mostly be ignored.  Feature requests are even more likely to be ignored.  (If
+  someone takes up maintenance of this code, they will presumably remove this
+  notice.) This means that whatever version of perl is currently required is
+  unlikely to change -- but also that it might change at any new maintainer's
+  whim.
+  END
 
-$WINDOW{none} = <<'END';
-This code is effectively abandonware.  Although releases will sometimes be made
-to update contact info or to fix packaging flaws, bug reports will mostly be
-ignored.  Feature requests are even more likely to be ignored.  (If someone
-takes up maintenance of this code, they will presumably remove this notice.)
-This means that whatever version of perl is currently required is unlikely to
-change -- but also that it might change at any new maintainer's whim.
-END
+my $STOCK = <<~'END';
+  Although it may work on older versions of perl, no guarantee is made that the
+  minimum required version will not be increased.  The version may be increased
+  for any reason, and there is no promise that patches will be accepted to
+  lower the minimum required perl.
+  END
 
-my $STOCK = <<'END';
-Although it may work on older versions of perl, no guarantee is made that the
-minimum required version will not be increased.  The version may be increased
-for any reason, and there is no promise that patches will be accepted to lower
-the minimum required perl.
-END
+$WINDOW{toolchain} = <<~"END";
+  This module is part of CPAN toolchain, or is treated as such.  As such, it
+  follows the agreement of the Perl Toolchain Gang to require no newer version
+  of perl than one released in the last ten years.  This version may change by
+  agreement of the Toolchain Gang, but for now is governed by the L<Lancaster
+  Consensus|https://github.com/Perl-Toolchain-Gang/toolchain-site/blob/master/lancaster-consensus.md>
+  of 2013 and the Lyon Amendment of 2023 (described at the linked-to document).
 
-$WINDOW{extreme} = <<"END";
-This library should run on perls released even an extremely long time ago.  It
-should work on any version of perl released in the last ten years.
+  $STOCK
+  END
 
-$STOCK
-END
+$WINDOW{extreme} = <<~"END";
+  This library should run on perls released even an extremely long time ago.  It
+  should work on any version of perl released in the last ten years.
 
-$WINDOW{'long-term'} = <<"END";
-This library should run on perls released even a long time ago.  It should work
-on any version of perl released in the last five years.
+  $STOCK
+  END
 
-$STOCK
-END
+$WINDOW{'long-term'} = <<~"END";
+  This library should run on perls released even a long time ago.  It should
+  work on any version of perl released in the last five years.
 
-$WINDOW{standard} = <<"END";
-This module should work on any version of perl still receiving updates from
-the Perl 5 Porters.  This means it should work on any version of perl released
-in the last two to three years.  (That is, if the most recently released
-version is v5.40, then this module should work on both v5.40 and v5.38.)
+  $STOCK
+  END
 
-$STOCK
-END
+$WINDOW{standard} = <<~"END";
+  This module should work on any version of perl still receiving updates from
+  the Perl 5 Porters.  This means it should work on any version of perl
+  released in the last two to three years.  (That is, if the most recently
+  released version is v5.40, then this module should work on both v5.40 and
+  v5.38.)
+
+  $STOCK
+  END
 
 # To be used almost exclusively on stuff that I write for my own use and ship
 # to CPAN as a matter of convenience, rather than for libraries I expect to
 # become part of anyone's software stack. -- rjbs, 2021-04-03
-$WINDOW{'no-mercy'} = <<"END";
-This module is shipped with no promise about what version of perl it will
-require in the future.  In practice, this tends to mean "you need a perl from
-the last three years," but you can't rely on that.  If a new version of perl
-ship, this software B<may> begin to require it for any reason, and there is no
-promise that patches will be accepted to lower the minimum required perl.
-END
+$WINDOW{'no-mercy'} = <<~"END";
+  This module is shipped with no promise about what version of perl it will
+  require in the future.  In practice, this tends to mean "you need a perl from
+  the last three years," but you can't rely on that.  If a new version of perl
+  ship, this software B<may> begin to require it for any reason, and there is
+  no promise that patches will be accepted to lower the minimum required perl.
+  END
 
 sub _perl_window_plugin {
   my ($self, $name) = @_;
@@ -149,7 +153,7 @@ Pod::Weaver::PluginBundle::RJBS - RJBS's default Pod::Weaver config
 
 =head1 VERSION
 
-version 5.023
+version 5.024
 
 =head1 OVERVIEW
 
@@ -172,8 +176,8 @@ C<-Transformer> with L<Pod::Elemental::Transformer::List>
 This module is shipped with no promise about what version of perl it will
 require in the future.  In practice, this tends to mean "you need a perl from
 the last three years," but you can't rely on that.  If a new version of perl
-ship, this software B<may> begin to require it for any reason, and there is no
-promise that patches will be accepted to lower the minimum required perl.
+ship, this software B<may> begin to require it for any reason, and there is
+no promise that patches will be accepted to lower the minimum required perl.
 
 =head1 AUTHOR
 
